@@ -12,7 +12,7 @@ import typing as t
 import zipfile
 from datetime import datetime
 
-__version__ = "0.2.2"
+__version__ = "0.2.4"
 
 
 parser = argparse.ArgumentParser(
@@ -36,10 +36,9 @@ parser.add_argument(
     help="Name des Projektes. Standard ist der Name von IN",
 )
 parser.add_argument(
-    "-c",
-    "--clear",
+    "--no-clear",
     dest="clear",
-    action="store_true",
+    action="store_false",
     help="Löscht den Zielordner, bevor die Projektversionen erstellt werden",
 )
 parser.add_argument(
@@ -234,7 +233,7 @@ def main() -> None:
 
     # build config for this run
     config = configparser.ConfigParser(
-        interpolation=None, converters={"list": lambda v: re.split(r"[,;\n]+", v), "liste": lambda v: v.split(",")}
+        interpolation=None, converters={"list": lambda v: re.split(r"[,;\n]+", v)}
     )
     # running list of patterns
     excludes = set()
@@ -272,7 +271,7 @@ def main() -> None:
     merge_configs(
         settings,
         args,
-        flags={"keep empty files": False, "create zip": True, "delete ml": True, "clear": True},
+        flags={"keep empty files": False, "create zip": True, "delete ml": True, "clear": False},
     )
     if project_root:
         settings["project root"] = project_root
@@ -410,7 +409,8 @@ def create_solution(config: configparser.ConfigParser) -> t.Set[str]:
                                 if len(parts) > 1:
                                     v_match = RE_VERSION2.match(parts[1])
                                     if v_match is not None:
-                                        versions.add(v_match.group(2))
+                                        for v in range(int(v_match.group(2))):
+                                            versions.add(f"{v+1}")
                                 skip = True
                             elif skip:
                                 pass
